searchData={"items":[{"type":"module","title":"Elnom","doc":"Convenience module for importing all of elnom's functionality at once.\n\nElnom has a lot of modules to mirror nom's module structure.  It's often easier just to\nimport everything at once, although entirely optional to do so.\n\nYou can choose to import either the string or bytes parsers, but not both.  If you're using\nstrings, you should use type `:string`.\n\n    use Elnom, type: :string\n\nIf you're only handling byte data, and no unicode characters, you should use type `:bytes`.\n\n    use Elnom, type: :bytes","ref":"Elnom.html"},{"type":"module","title":"Elnom.Branch","doc":"Choice combinators.","ref":"Elnom.Branch.html"},{"type":"function","title":"Elnom.Branch.alt/1","doc":"Tests a list of parsers one by one until one succeeds.\n\nIt takes as argument a tuple or list of parsers.\n\n    iex> parser = alt({alpha1(), digit1()})\n    iex> parser.(\"abc\")\n    {:ok, \"\", \"abc\"}\n    iex> parser.(\"123456\")\n    {:ok, \"\", \"123456\"}\n    iex> parser.(\"abc123\")\n    {:ok, \"123\", \"abc\"}\n    iex> parser.(\" \")\n    {:error, %Error{kind: :digit, buffer: \" \"}}","ref":"Elnom.Branch.html#alt/1"},{"type":"function","title":"Elnom.Branch.permutation/1","doc":"Applies a list of parsers in any order.\n\nPermutation will succeed if all of the child parsers succeeded. It takes as argument a tuple of parsers, and returns a tuple of the parser results.\n\n    iex> parser = permutation({alpha1(), digit1()})\n    iex> parser.(\"abc123\")\n    {:ok, \"\", {\"abc\", \"123\"}}\n    iex> parser.(\"123abc\")\n    {:ok, \"\", {\"abc\", \"123\"}}\n    iex> parser.(\"abc;\")\n    {:error, %Error{kind: :digit, buffer: \";\"}}\n\nThe parsers are applied greedily: if there are multiple unapplied parsers that could parse the next slice of input, the first one is used.\n\n    iex> parser = permutation({anychar(), char(\"a\")})\n    iex> parser.(\"ba\")\n    {:ok, \"\", {\"b\", \"a\"}}\n    iex> parser.(\"ab\")\n    {:error, %Error{kind: :char, buffer: \"b\"}}","ref":"Elnom.Branch.html#permutation/1"},{"type":"module","title":"Elnom.Bytes.Complete","doc":"Parsers recognising byte streams.  Only for use with bitstrings, use `Elnom.Strings.Complete` for strings.","ref":"Elnom.Bytes.Complete.html"},{"type":"function","title":"Elnom.Bytes.Complete.escaped/3","doc":"Matches a bitstring with escaped bytes.\n\nWarning: This function is for use with bitstrings only.  For strings, use\n`Elnom.Strings.Complete.escaped/3`.\n\nThe first argument matches the normal bytes (it must not accept the control byte)\nThe second argument is the control byte\nThe third argument matches the escaped bytes\n\n    iex> esc = escaped(is_a( >),  >, one_of( >))\n    iex> esc.( >)\n    {:ok,  >,  >}\n    iex> esc.( >)\n    {:ok,  >,  >}","ref":"Elnom.Bytes.Complete.html#escaped/3"},{"type":"function","title":"Elnom.Bytes.Complete.escaped_transform/3","doc":"Matches a bitstring with escaped bytes.\n\nWarning: This function is for use with bitstrings only.  For strings, use\n`Elnom.Strings.Complete.escaped_transform/3`.\n\n* The first argument matches the normal bytes (it must not match the control byte)\n* The second argument is the control byte\n* The third argument matches the escaped bytes and transforms them\n\nExample:\n\n    iex> esc = escaped_transform(\n    ...>   is_a( >),\n    ...>    >,\n    ...>   alt({\n    ...>     value( >, tag( >)),\n    ...>     value( >, tag( >)),\n    ...>     value( >, tag( >))\n    ...>   })\n    ...> )\n    iex> esc.( >)\n    {:ok,  >,  >}\n    iex> esc.( >)\n    {:ok,  >,  >}","ref":"Elnom.Bytes.Complete.html#escaped_transform/3"},{"type":"function","title":"Elnom.Bytes.Complete.is_a/1","doc":"Returns the longest match of the matches the pattern.\n\nWarning: This function is for use with bitstrings only.  For strings, use\n`Elnom.Strings.Complete.is_a/1`.\n\nThe parser will return the longest match consisting of the bytes in provided in the combinator’s argument.\n\nIt will return an Error if the pattern wasn’t met.\n\n    iex> hex = is_a( >)\n    iex> hex.( >)\n    {:ok,  >,  >}\n    iex> hex.( >)\n    {:error, %Error{kind: :is_a, buffer:  >}}\n    iex> hex.( >)\n    {:error, %Error{kind: :is_a, buffer:  >}}","ref":"Elnom.Bytes.Complete.html#is_a/1"},{"type":"function","title":"Elnom.Bytes.Complete.is_not/1","doc":"Parse till certain characters are met.\n\nWarning: This function is for use with bitstrings only.  For strings, use\n`Elnom.Strings.Complete.is_not/1`.\n\nThe parser will return the longest match till one of the characters of the combinator’s argument are met.\n\nIt doesn’t consume the matched character.\n\n    iex> parser = is_not( >)\n    iex> parser.( >)\n    {:ok,  >,  >}\n    iex> parser.( >)\n    {:ok,  >,  >}\n    iex> parser.( >)\n    {:error, %Error{kind: :is_not, buffer:  >}}\n    iex> parser.(\"\")\n    {:error, %Error{kind: :is_not, buffer: \"\"}}","ref":"Elnom.Bytes.Complete.html#is_not/1"},{"type":"function","title":"Elnom.Bytes.Complete.tag/1","doc":"Recognizes a pattern\n\nThe input data will be compared to the tag combinator’s argument and will return the part of the input that matches the argument.\n\nIt will return an Error if the input doesn’t match the pattern.\n\n    iex> tag(\"hello\").(\"hello there\")\n    {:ok, \" there\", \"hello\"}\n    iex> tag(\"hello\").(\"bye\")\n    {:error, %Error{kind: :tag, buffer: \"bye\"}}\n    iex> tag(\"\").(\"bye\")\n    {:ok, \"bye\", \"\"}\n    iex> tag(\"💙\").(\"💙💙\")\n    {:ok, \"💙\", \"💙\"}","ref":"Elnom.Bytes.Complete.html#tag/1"},{"type":"function","title":"Elnom.Bytes.Complete.take/1","doc":"Returns an input substring containing the first `count` input bytes.\n\nWarning: This function is for use with bitstrings only.  For strings, use\n`Elnom.Strings.Complete.take/1`.\n\nIt will return Error if the input is shorter than the argument.\n\n    iex> take(1).(\"💙\")\n    {:ok,  >,  >}\n\n    iex> take6 = take(6)\n    iex> take6.( >)\n    {:ok,  >,  >}\n    iex> take6.( >)\n    {:ok,  >,  >}\n    iex> take6.( >)\n    {:error, %Error{kind: :eof, buffer:  >}}\n    iex> take6.( >)\n    {:error, %Error{kind: :eof, buffer:  >}}","ref":"Elnom.Bytes.Complete.html#take/1"},{"type":"function","title":"Elnom.Bytes.Complete.take_till1/1","doc":"Returns the longest matching input (at least 1) till a predicate is met.\n\nWarning: This function is for use with bitstrings only.  For strings, use\n`Elnom.Strings.Complete.take_till1/1`.\n\nThe parser will return the longest match till the given predicate (a function that takes the input and returns a bool).\n\nIt will return Error if the input is empty or the predicate matches the first input.\n\n    iex> till_colon = take_till1(fn byte -> byte > 200 end)\n    iex> till_colon.( >)\n    {:ok,  >,  >}\n    iex> till_colon.( >)\n    {:error, %Error{kind: :take_till1, buffer:  >}}\n    iex> till_colon.( >)\n    {:ok,  >,  >}\n    iex> till_colon.( >)\n    {:error, %Error{kind: :take_till1, buffer:  >}}","ref":"Elnom.Bytes.Complete.html#take_till1/1"},{"type":"function","title":"Elnom.Bytes.Complete.take_till/1","doc":"Returns the longest matching input (if any) till a predicate is met.\n\nWarning: This function is for use with bitstrings only.  For strings, use\n`Elnom.Strings.Complete.take_till/1`.\n\nThe parser will return the longest match till the given predicate (a function that takes the input and returns a bool).\n\n    iex> till_colon = take_till(fn byte -> byte > 200 end)\n    iex> till_colon.( >)\n    {:ok,  >,  >}\n    iex> till_colon.( >)\n    {:ok,  >,  >}\n    iex> till_colon.( >)\n    {:ok,  >,  >}\n    iex> till_colon.( >)\n    {:ok,  >,  >}","ref":"Elnom.Bytes.Complete.html#take_till/1"},{"type":"function","title":"Elnom.Bytes.Complete.take_until1/1","doc":"Returns the non empty input up to the first occurrence of the pattern.\n\nWarning: This function is for use with bitstrings only.  For strings, use\n`Elnom.Strings.Complete.take_until1/1`.\n\nIt doesn’t consume the pattern. It will return Error if the pattern wasn’t met.\n\n    iex> until_eof = take_until1( >)\n    iex> until_eof.( >)\n    {:ok,  >,  >}\n    iex> until_eof.( >)\n    {:error, %Error{kind: :take_until, buffer:  >}}\n    iex> until_eof.( >)\n    {:error, %Error{kind: :take_until, buffer:  >}}\n    iex> until_eof.( >)\n    {:error, %Error{kind: :take_until, buffer:  >}}","ref":"Elnom.Bytes.Complete.html#take_until1/1"},{"type":"function","title":"Elnom.Bytes.Complete.take_until/1","doc":"Returns the input up to the first occurrence of the pattern.\n\nWarning: This function is for use with bitstrings only.  For strings, use\n`Elnom.Strings.Complete.take_until/1`.\n\nIt doesn’t consume the pattern. It will return Error if the pattern wasn’t met.\n\n    iex> until_eof = take_until( >)\n    iex> until_eof.( >)\n    {:ok,  >,  >}\n    iex> until_eof.( >)\n    {:error, %Error{kind: :take_until, buffer:  >}}\n    iex> until_eof.( >)\n    {:ok,  >,  >}\n    iex> until_eof.( >)\n    {:error, %Error{kind: :take_until, buffer:  >}}","ref":"Elnom.Bytes.Complete.html#take_until/1"},{"type":"function","title":"Elnom.Bytes.Complete.take_while1/2","doc":"Returns the longest (at least 1) input match that matches the predicate.\n\nWarning: This function is for use with bitstrings only.  For strings, use\n`Elnom.Strings.Complete.take_while1/1`.\n\nThe parser will return the longest match that matches the given predicate (a function that takes the input and returns a bool).\n\nIt will return an Error if the pattern wasn’t met.\n\n    iex> high = take_while1(fn byte -> byte >= 200 end)\n    iex> high.( >)\n    {:ok,  >,  >}\n    iex> high.( >)\n    {:error, %Error{kind: :take_while1, buffer:  >}}\n    iex> high.( >)\n    {:ok,  >,  >}\n    iex> high.( >)\n    {:error, %Error{kind: :take_while1, buffer:  >}}","ref":"Elnom.Bytes.Complete.html#take_while1/2"},{"type":"function","title":"Elnom.Bytes.Complete.take_while/1","doc":"Returns the longest input match (if any) that matches the predicate.\n\nWarning: This function is for use with bitstrings only.  For strings, use\n`Elnom.Strings.Complete.take_while/1`.\n\nThe parser will return the longest match that matches the given predicate (a function that takes the input and returns a bool).\n\n    iex> high = take_while(fn byte -> byte >= 200 end)\n    iex> high.( >)\n    {:ok,  >,  >}\n    iex> high.( >)\n    {:ok,  >,  >}\n    iex> high.( >)\n    {:ok,  >,  >}\n    iex> high.( >)\n    {:ok,  >,  >}","ref":"Elnom.Bytes.Complete.html#take_while/1"},{"type":"function","title":"Elnom.Bytes.Complete.take_while_m_n/3","doc":"Returns the longest (min   short_alpha = take_while_m_n(3, 6, fn byte -> byte >= 200 end)\n    iex> short_alpha.( >)\n    {:ok,  >,  >}\n    iex> short_alpha.( >)\n    {:ok,  >,  >}\n    iex> short_alpha.( >)\n    {:ok,  >,  >}\n    iex> short_alpha.( >)\n    {:error, %Error{kind: :take_while_m_n, buffer:  >}}\n    iex> short_alpha.( >)\n    {:error, %Error{kind: :take_while_m_n, buffer:  >}}","ref":"Elnom.Bytes.Complete.html#take_while_m_n/3"},{"type":"module","title":"Elnom.Character","doc":"Character-specific parsers and combinators","ref":"Elnom.Character.html"},{"type":"function","title":"Elnom.Character.is_alphabetic/1","doc":"Matches characters a..z, A..Z","ref":"Elnom.Character.html#is_alphabetic/1"},{"type":"function","title":"Elnom.Character.is_alphanumeric/1","doc":"Matches characters a..z, A..Z, 0..9","ref":"Elnom.Character.html#is_alphanumeric/1"},{"type":"function","title":"Elnom.Character.is_bin_digit/1","doc":"Matches characters 0..1","ref":"Elnom.Character.html#is_bin_digit/1"},{"type":"function","title":"Elnom.Character.is_digit/1","doc":"Matches characters 0..9","ref":"Elnom.Character.html#is_digit/1"},{"type":"function","title":"Elnom.Character.is_hex_digit/1","doc":"Matches characters 0..9, a..f, A..F","ref":"Elnom.Character.html#is_hex_digit/1"},{"type":"function","title":"Elnom.Character.is_newline/1","doc":"Matches the newline character","ref":"Elnom.Character.html#is_newline/1"},{"type":"function","title":"Elnom.Character.is_oct_digit/1","doc":"Matches characters 0..7","ref":"Elnom.Character.html#is_oct_digit/1"},{"type":"function","title":"Elnom.Character.is_space/1","doc":"Matches space and tab characters","ref":"Elnom.Character.html#is_space/1"},{"type":"module","title":"Elnom.Character.Complete","doc":"Parser functions recognizing specific characters","ref":"Elnom.Character.Complete.html"},{"type":"function","title":"Elnom.Character.Complete.alpha0/0","doc":"Recognizes zero or more lowercase and uppercase ASCII alphabetic characters: a-z, A-Z\n\nComplete version: Will return the whole input if no terminating token is found (a non alphabetic character).\n\n    iex> alpha0().(\"aB1c\")\n    {:ok, \"1c\", \"aB\"}\n    iex> alpha0().(\"1c\")\n    {:ok, \"1c\", \"\"}\n    iex> alpha0().(\"\")\n    {:ok, \"\", \"\"}","ref":"Elnom.Character.Complete.html#alpha0/0"},{"type":"function","title":"Elnom.Character.Complete.alpha1/0","doc":"Recognizes one or more lowercase and uppercase ASCII alphabetic characters: a-z, A-Z\n\nComplete version: Will return an error if there’s not enough input data, or the whole input if no terminating token is found (a non alphabetic character).\n\n    iex> alpha1().(\"aB1c\")\n    {:ok, \"1c\", \"aB\"}\n    iex> alpha1().(\"1c\")\n    {:error, %Error{kind: :alpha, buffer: \"1c\"}}\n    iex> alpha1().(\"\")\n    {:error, %Error{kind: :alpha, buffer: \"\"}}","ref":"Elnom.Character.Complete.html#alpha1/0"},{"type":"function","title":"Elnom.Character.Complete.alphanumeric0/0","doc":"Recognizes zero or more ASCII numerical and alphabetic characters: 0-9, a-z, A-Z\n\nComplete version: Will return the whole input if no terminating token is found (a non alphanumerical character).\n\n    iex> alphanumeric0().(\"21cZ%1\")\n    {:ok, \"%1\", \"21cZ\"}\n    iex> alphanumeric0().(\"%1\")\n    {:ok, \"%1\", \"\"}\n    iex> alphanumeric0().(\"\")\n    {:ok, \"\", \"\"}","ref":"Elnom.Character.Complete.html#alphanumeric0/0"},{"type":"function","title":"Elnom.Character.Complete.alphanumeric1/0","doc":"Recognizes one or more ASCII numerical and alphabetic characters: 0-9, a-z, A-Z\n\nComplete version: Will return an error if there’s not enough input data, or the whole input if no terminating token is found (a non alphanumerical character).\n\n    iex> alphanumeric1().(\"21cZ%1\")\n    {:ok, \"%1\", \"21cZ\"}\n    iex> alphanumeric1().(\"%1\")\n    {:error, %Error{kind: :alphanumeric, buffer: \"%1\"}}\n    iex> alphanumeric1().(\"\")\n    {:error, %Error{kind: :alphanumeric, buffer: \"\"}}","ref":"Elnom.Character.Complete.html#alphanumeric1/0"},{"type":"function","title":"Elnom.Character.Complete.anychar/0","doc":"Matches one utf-8 character.\n\nComplete version: Will return an error if there’s not enough input data.\n\n    iex> anychar().(\"abc\")\n    {:ok, \"bc\", \"a\"}\n    iex> anychar().(\"\")\n    {:error, %Error{kind: :anychar, buffer: \"\"}}","ref":"Elnom.Character.Complete.html#anychar/0"},{"type":"function","title":"Elnom.Character.Complete.char/1","doc":"Recognizes one utf-8 character.\n\nComplete version: Will return an error if there’s not enough input data.\n\n    iex> char(\"h\").(\"hello\")\n    {:ok, \"ello\", \"h\"}\n    iex> char(\"e\").(\"hello\")\n    {:error, %Error{kind: :char, buffer: \"hello\"}}","ref":"Elnom.Character.Complete.html#char/1"},{"type":"function","title":"Elnom.Character.Complete.crlf/0","doc":"Recognizes the string “\\r\\n”.\n\nComplete version: Will return an error if there’s not enough input data.\n\n    iex> crlf().(\"\\r\\nc\")\n    {:ok, \"c\", \"\\r\\n\"}\n    iex> crlf().(\"ab\\r\\nc\")\n    {:error, %Error{kind: :crlf, buffer: \"ab\\r\\nc\"}}\n    iex> crlf().(\"\")\n    {:error, %Error{kind: :crlf, buffer: \"\"}}","ref":"Elnom.Character.Complete.html#crlf/0"},{"type":"function","title":"Elnom.Character.Complete.digit0/0","doc":"Recognizes zero or more ASCII numerical characters: 0-9\n\nComplete version: Will return an error if there’s not enough input data, or the whole input if no terminating token is found (a non digit character).\n\n    iex> digit0().(\"21c\")\n    {:ok, \"c\", \"21\"}\n    iex> digit0().(\"21\")\n    {:ok, \"\", \"21\"}\n    iex> digit0().(\"a21c\")\n    {:ok, \"a21c\", \"\"}\n    iex> digit0().(\"\")\n    {:ok, \"\", \"\"}","ref":"Elnom.Character.Complete.html#digit0/0"},{"type":"function","title":"Elnom.Character.Complete.digit1/0","doc":"Recognizes one or more ASCII numerical characters: 0-9\n\nComplete version: Will return an error if there’s not enough input data, or the whole input if no terminating token is found (a non digit character).\n\n    iex> digit1().(\"213c\")\n    {:ok, \"c\", \"213\"}\n    iex> digit1().(\"c1\")\n    {:error, %Error{kind: :digit, buffer: \"c1\"}}\n    iex> digit1().(\"\")\n    {:error, %Error{kind: :digit, buffer: \"\"}}\n\nYou can use this function in combination with `Elnom.Combinator.map/2` to parse an integer:\n\n    iex> parser = map(digit1(), &String.to_integer/1)\n    iex> parser.(\"123abc\")\n    {:ok, \"abc\", 123}","ref":"Elnom.Character.Complete.html#digit1/0"},{"type":"function","title":"Elnom.Character.Complete.hex_digit0/0","doc":"Recognizes zero or more ASCII hexadecimal numerical characters: 0-9, A-F, a-f\n\nComplete version: Will return the whole input if no terminating token is found (a non hexadecimal digit character).\n\n    iex> hex_digit0().(\"21cZ\")\n    {:ok, \"Z\", \"21c\"}\n    iex> hex_digit0().(\"%1\")\n    {:ok, \"%1\", \"\"}\n    iex> hex_digit0().(\"\")\n    {:ok, \"\", \"\"}","ref":"Elnom.Character.Complete.html#hex_digit0/0"},{"type":"function","title":"Elnom.Character.Complete.hex_digit1/0","doc":"Recognizes one or more ASCII hexadecimal numerical characters: 0-9, A-F, a-f\n\nComplete version: Will return an error if there’s not enough input data, or the whole input if no terminating token is found (a non hexadecimal digit character).\n\n    iex> hex_digit1().(\"21cZ\")\n    {:ok, \"Z\", \"21c\"}\n    iex> hex_digit1().(\"%1\")\n    {:error, %Error{kind: :hex_digit, buffer: \"%1\"}}\n    iex> hex_digit1().(\"\")\n    {:error, %Error{kind: :hex_digit, buffer: \"\"}}","ref":"Elnom.Character.Complete.html#hex_digit1/0"},{"type":"function","title":"Elnom.Character.Complete.i8/0","doc":"See `integer/0`","ref":"Elnom.Character.Complete.html#i8/0"},{"type":"function","title":"Elnom.Character.Complete.i16/0","doc":"See `integer/0`","ref":"Elnom.Character.Complete.html#i16/0"},{"type":"function","title":"Elnom.Character.Complete.i32/0","doc":"See `integer/0`","ref":"Elnom.Character.Complete.html#i32/0"},{"type":"function","title":"Elnom.Character.Complete.i64/0","doc":"See `integer/0`","ref":"Elnom.Character.Complete.html#i64/0"},{"type":"function","title":"Elnom.Character.Complete.i128/0","doc":"See `integer/0`","ref":"Elnom.Character.Complete.html#i128/0"},{"type":"function","title":"Elnom.Character.Complete.integer/0","doc":"Parses a number in text form to an integer.\n\nThis function does not exist in Rust's nom library because it uses u8(), i8, u16(), etc. to convert to integers.  Elixir doesn't have these types, so this single function can translate a string to an integer of any size.\n\nComplete version: Will return an error if there’s not enough input data, or the whole input if no terminating token is found (a non digit character).\n\n    iex> integer().(\"123abc\")\n    {:ok, \"abc\", 123}\n    iex> integer().(\"abc\")\n    {:error, %Error{kind: :digit, buffer: \"abc\"}}\n    iex> integer().(\"\")\n    {:error, %Error{kind: :digit, buffer: \"\"}}","ref":"Elnom.Character.Complete.html#integer/0"},{"type":"function","title":"Elnom.Character.Complete.line_ending/0","doc":"Recognizes an end of line (both ‘\\n’ and ‘\\r\\n’).\n\nComplete version: Will return an error if there’s not enough input data.\n\n    iex> line_ending().(\"\\r\\nc\")\n    {:ok, \"c\", \"\\r\\n\"}\n    iex> line_ending().(\"ab\\r\\nc\")\n    {:error, %Error{kind: :cr_lf, buffer: \"ab\\r\\nc\"}}\n    iex> line_ending().(\"\")\n    {:error, %Error{kind: :cr_lf, buffer: \"\"}}","ref":"Elnom.Character.Complete.html#line_ending/0"},{"type":"function","title":"Elnom.Character.Complete.multispace0/0","doc":"Recognizes zero or more spaces, tabs, carriage returns and line feeds.\n\nComplete version: will return the whole input if no terminating token is found (a non space character).\n\n    iex> multispace0().(\" \\t\\n\\r21c\")\n    {:ok, \"21c\", \" \\t\\n\\r\"}\n    iex> multispace0().(\"Z21c\")\n    {:ok, \"Z21c\", \"\"}\n    iex> multispace0().(\"\")\n    {:ok, \"\", \"\"}","ref":"Elnom.Character.Complete.html#multispace0/0"},{"type":"function","title":"Elnom.Character.Complete.multispace1/0","doc":"Recognizes one or more spaces, tabs, carriage returns and line feeds.\n\nComplete version: will return an error if there’s not enough input data, or the whole input if no terminating token is found (a non space character).\n\n    iex> multispace1().(\" \\t\\n\\r21c\")\n    {:ok, \"21c\", \" \\t\\n\\r\"}\n    iex> multispace1().(\"Z21c\")\n    {:error, %Error{kind: :multispace, buffer: \"Z21c\"}}\n    iex> multispace1().(\"\")\n    {:error, %Error{kind: :multispace, buffer: \"\"}}","ref":"Elnom.Character.Complete.html#multispace1/0"},{"type":"function","title":"Elnom.Character.Complete.newline/0","doc":"Matches a newline character ‘\\n’.\n\nComplete version: Will return an error if there’s not enough input data.\n\n    iex> newline().(\"\\nc\")\n    {:ok, \"c\", \"\\n\"}\n    iex> newline().(\"\\r\\nc\")\n    {:error, %Error{kind: :newline, buffer: \"\\r\\nc\"}}\n    iex> newline().(\"\")\n    {:error, %Error{kind: :newline, buffer: \"\"}}","ref":"Elnom.Character.Complete.html#newline/0"},{"type":"function","title":"Elnom.Character.Complete.none_of/1","doc":"Recognizes a character that is not in the provided characters.\n\nComplete version: Will return an error if there’s not enough input data.\n\n    iex> none_of(\"abc\").(\"z\")\n    {:ok, \"\", \"z\"}\n    iex> none_of(\"ab\").(\"a\")\n    {:error, %Error{kind: :none_of, buffer: \"a\"}}\n    iex> none_of(\"a\").(\"\")\n    {:error, %Error{kind: :none_of, buffer: \"\"}}","ref":"Elnom.Character.Complete.html#none_of/1"},{"type":"function","title":"Elnom.Character.Complete.not_line_ending/0","doc":"Recognizes a string of any char except ‘\\r\\n’ or ‘\\n’.\n\nComplete version: Will return an error if there’s not enough input data.\n\n    iex> not_line_ending().(\"ab\\r\\nc\")\n    {:ok, \"\\r\\nc\", \"ab\"}\n    iex> not_line_ending().(\"ab\\nc\")\n    {:ok, \"\\nc\", \"ab\"}\n    iex> not_line_ending().(\"abc\")\n    {:ok, \"\", \"abc\"}\n    iex> not_line_ending().(\"\")\n    {:ok, \"\", \"\"}\n    iex> not_line_ending().(\"a\\rb\\nc\")\n    {:error, %Error{kind: :tag, buffer: \"a\\rb\\nc\"}}","ref":"Elnom.Character.Complete.html#not_line_ending/0"},{"type":"function","title":"Elnom.Character.Complete.oct_digit0/0","doc":"Recognizes zero or more octal characters: 0-7\n\nComplete version: Will return the whole input if no terminating token is found (a non octal digit character).\n\n    iex> oct_digit0().(\"21cZ\")\n    {:ok, \"cZ\", \"21\"}\n    iex> oct_digit0().(\"%1\")\n    {:ok, \"%1\", \"\"}\n    iex> oct_digit0().(\"\")\n    {:ok, \"\", \"\"}","ref":"Elnom.Character.Complete.html#oct_digit0/0"},{"type":"function","title":"Elnom.Character.Complete.oct_digit1/0","doc":"Recognizes one or more octal characters: 0-7\n\nComplete version: Will return an error if there’s not enough input data, or the whole input if no terminating token is found (a non octal digit character).\n\n    iex> oct_digit1().(\"218cZ\")\n    {:ok, \"8cZ\", \"21\"}\n    iex> oct_digit1().(\"%1\")\n    {:error, %Error{kind: :oct_digit, buffer: \"%1\"}}\n    iex> oct_digit1().(\"\")\n    {:error, %Error{kind: :oct_digit, buffer: \"\"}}","ref":"Elnom.Character.Complete.html#oct_digit1/0"},{"type":"function","title":"Elnom.Character.Complete.one_of/1","doc":"Recognizes one of the provided utf-8 characters.\n\nComplete version: Will return an error if there’s not enough input data.\n\n    iex> one_of(\"abc\").(\"b\")\n    {:ok, \"\", \"b\"}\n    iex> one_of(\"a\").(\"bc\")\n    {:error, %Error{kind: :one_of, buffer: \"bc\"}}\n    iex> one_of(\"a\").(\"\")\n    {:error, %Error{kind: :one_of, buffer: \"\"}}","ref":"Elnom.Character.Complete.html#one_of/1"},{"type":"function","title":"Elnom.Character.Complete.satisfy/1","doc":"Recognizes one utf-8 character and checks that it satisfies a predicate\n\nComplete version: Will return an error if there’s not enough input data.\n\n    iex> parser = satisfy(&(&1 == ?a || &1 == ?b))\n    iex> parser.(\"abc\")\n    {:ok, \"bc\", \"a\"}\n    iex> parser.(\"cd\")\n    {:error, %Error{kind: :satisfy, buffer: \"cd\"}}\n    iex> parser.(\"\")\n    {:error, %Error{kind: :satisfy, buffer: \"\"}}","ref":"Elnom.Character.Complete.html#satisfy/1"},{"type":"function","title":"Elnom.Character.Complete.space0/0","doc":"Recognizes zero or more spaces and tabs.\n\nComplete version: Will return the whole input if no terminating token is found (a non space character).\n\n    iex> space0().(\" \\t21c\")\n    {:ok, \"21c\", \" \\t\"}\n    iex> space0().(\"Z21c\")\n    {:ok, \"Z21c\", \"\"}\n    iex> space0().(\"\")\n    {:ok, \"\", \"\"}","ref":"Elnom.Character.Complete.html#space0/0"},{"type":"function","title":"Elnom.Character.Complete.space1/0","doc":"Recognizes one or more spaces and tabs.\n\nComplete version: Will return an error if there’s not enough input data, or the whole input if no terminating token is found (a non space character).\n\n    iex> space1().(\" \\t21c\")\n    {:ok, \"21c\", \" \\t\"}\n    iex> space1().(\"Z21c\")\n    {:error, %Error{kind: :space, buffer: \"Z21c\"}}\n    iex> space1().(\"\")\n    {:error, %Error{kind: :space, buffer: \"\"}}","ref":"Elnom.Character.Complete.html#space1/0"},{"type":"function","title":"Elnom.Character.Complete.tab/0","doc":"Matches a tab character ‘\\t’.\n\nComplete version: Will return an error if there’s not enough input data.\n\n    iex> tab().(\"\\tc\")\n    {:ok, \"c\", \"\\t\"}\n    iex> tab().(\"\\r\\nc\")\n    {:error, %Error{kind: :char, buffer: \"\\r\\nc\"}}\n    iex> tab().(\"\")\n    {:error, %Error{kind: :char, buffer: \"\"}}","ref":"Elnom.Character.Complete.html#tab/0"},{"type":"function","title":"Elnom.Character.Complete.u8/0","doc":"See `integer/0`","ref":"Elnom.Character.Complete.html#u8/0"},{"type":"function","title":"Elnom.Character.Complete.u16/0","doc":"See `integer/0`","ref":"Elnom.Character.Complete.html#u16/0"},{"type":"function","title":"Elnom.Character.Complete.u32/0","doc":"See `integer/0`","ref":"Elnom.Character.Complete.html#u32/0"},{"type":"function","title":"Elnom.Character.Complete.u64/0","doc":"See `integer/0`","ref":"Elnom.Character.Complete.html#u64/0"},{"type":"function","title":"Elnom.Character.Complete.u128/0","doc":"See `integer/0`","ref":"Elnom.Character.Complete.html#u128/0"},{"type":"module","title":"Elnom.Combinator","doc":"General purpose combinators","ref":"Elnom.Combinator.html"},{"type":"function","title":"Elnom.Combinator.all_consuming/1","doc":"Succeeds if all the input has been consumed by its child parser.\n\n    iex> parser = all_consuming(tag(\"abc\"))\n    iex> parser.(\"abc\")\n    {:ok, \"\", \"abc\"}\n    iex> parser.(\"abc123\")\n    {:error, %Error{kind: :all_consuming, buffer: \"123\"}}\n    iex> parser.(\"ab\")\n    {:error, %Error{kind: :tag, buffer: \"ab\"}}","ref":"Elnom.Combinator.html#all_consuming/1"},{"type":"function","title":"Elnom.Combinator.complete/1","doc":"Transforms an Incomplete error into an Error.\n\n    iex> parser = complete(length_data(u8(), :byte))\n    iex> parser.( >)\n    {:ok, \"fg\", \"abcde\"}\n    iex> parser.( >)\n    {:error, %Error{kind: :complete, buffer:  >}}","ref":"Elnom.Combinator.html#complete/1"},{"type":"function","title":"Elnom.Combinator.cond/2","doc":"Calls the parser if the condition is met.\n\n    iex> parser = fn b -> cond(b, alpha1()) end\n    iex> parser.(true).(\"abcd;\")\n    {:ok, \";\", \"abcd\"}\n    iex> parser.(false).(\"abcd;\")\n    {:ok, \"abcd;\", nil}\n    iex> parser.(true).(\"123;\")\n    {:error, %Error{kind: :alpha, buffer: \"123;\"}}\n    iex> parser.(false).(\"123;\")\n    {:ok, \"123;\", nil}","ref":"Elnom.Combinator.html#cond/2"},{"type":"function","title":"Elnom.Combinator.consumed/1","doc":"If the child parser was successful, return the consumed input with the output as a tuple. Functions similarly to recognize/1 except it returns the parser output as well.\n\nThis can be useful especially in cases where the output is not the same type as the input, or the input is a user defined type.\n\nReturned tuple is of the format {consumed input, produced output}.\n\n    iex> parser = consumed(value(true, tag(\"abc\")))\n    iex> parser.(\"abcdef\")\n    {:ok, \"def\", {\"abc\", true}}","ref":"Elnom.Combinator.html#consumed/1"},{"type":"function","title":"Elnom.Combinator.cut/1","doc":"Transforms an Error (recoverable) to Failure (unrecoverable)\n\nThis commits the parse result, preventing alternative branch paths like with Elnom.Branch.alt/1.\n\nWithout cut/1:\n    iex> parser = alt({preceded(one_of(\"+-\"), digit1()), rest()})\n    iex> parser.(\"+10 ab\")\n    {:ok, \" ab\", \"10\"}\n    iex> parser.(\"ab\")\n    {:ok, \"\", \"ab\"}\n    iex> parser.(\"+\")\n    {:ok, \"\", \"+\"}\n\nWith cut/1:\n    iex> parser = alt({preceded(one_of(\"+-\"), cut(digit1())), rest()})\n    iex> parser.(\"+10 ab\")\n    {:ok, \" ab\", \"10\"}\n    iex> parser.(\"ab\")\n    {:ok, \"\", \"ab\"}\n    iex> parser.(\"+\")\n    {:error, %Failure{kind: :digit, buffer: \"\"}}","ref":"Elnom.Combinator.html#cut/1"},{"type":"function","title":"Elnom.Combinator.eof/0","doc":"Returns its input if it is at the end of input data.\n\nWhen we're at the end of the data, this combinator will succeed.\n\n    iex> eof().(\"abc\")\n    {:error, %Error{kind: :eof, buffer: \"abc\"}}\n    iex> eof().(\"\")\n    {:ok, \"\", \"\"}","ref":"Elnom.Combinator.html#eof/0"},{"type":"function","title":"Elnom.Combinator.fail/0","doc":"A parser which always fails.\n\n    iex> fail().(\"abc\")\n    {:error, %Error{kind: :fail, buffer: \"abc\"}}","ref":"Elnom.Combinator.html#fail/0"},{"type":"function","title":"Elnom.Combinator.flat_map/2","doc":"Creates a new parser from the output of the first parser, then apply that parser over the rest of the input.\n\n    iex> parser = flat_map(u8(), &take/1)\n    iex> parser.( >)\n    {:ok,  >,  >}\n    iex> parser.( >)\n    {:error, %Error{kind: :eof, buffer:  >}}","ref":"Elnom.Combinator.html#flat_map/2"},{"type":"function","title":"Elnom.Combinator.map/2","doc":"Maps a function on the result of a parser.\n\n    iex> parser = map(digit1(), &String.length/1)\n    iex> parser.(\"123456\")\n    {:ok, \"\", 6}\n    iex> parser.(\"abc\")\n    {:error, %Error{kind: :digit, buffer: \"abc\"}}","ref":"Elnom.Combinator.html#map/2"},{"type":"function","title":"Elnom.Combinator.map_parser/2","doc":"Applies a parser over the result of another one.\n\n    iex> parser = map_parser(take(5), digit1())\n    iex> parser.(\"123456\")\n    {:ok, \"6\", \"12345\"}\n    iex> parser.(\"123ab6\")\n    {:ok, \"6\", \"123\"}\n    iex> parser.(\"123\")\n    {:error, %Error{kind: :eof, buffer: \"123\"}}\n    iex> parser.(\"abcdef\")\n    {:error, %Error{kind: :digit, buffer: \"abcde\"}}","ref":"Elnom.Combinator.html#map_parser/2"},{"type":"function","title":"Elnom.Combinator.map_res/2","doc":"Applies a function successfully when returning {:ok, data} or unsuccesfully when returning anything else on the result of a parser.\n\n    iex> to_integer = fn str ->\n    ...>   case Integer.parse(str) do\n    ...>     {int, \"\"} -> {:ok, int}\n    ...>     _ -> :error\n    ...>   end\n    ...> end\n    iex> parser = map_res(take(3), to_integer)\n    iex> parser.(\"123abc\")\n    {:ok, \"abc\", 123}\n    iex> parser.(\"abc\")\n    :error","ref":"Elnom.Combinator.html#map_res/2"},{"type":"function","title":"Elnom.Combinator.not_/1","doc":"Succeeds if the child parser returns an error.\n\nBecause Elixir has a reserved `not` function, this combinator is named `not_`.\n\n    iex> parser = not_(alpha1())\n    iex> parser.(\"123\")\n    {:ok, \"123\", nil}\n    iex> parser.(\"abc\")\n    {:error, %Error{kind: :not, buffer: \"abc\"}}","ref":"Elnom.Combinator.html#not_/1"},{"type":"function","title":"Elnom.Combinator.opt/1","doc":"Optional parser, will return nil on Error.\n\nTo chain an error up, see cut/1.\n\n    iex> parser = opt(alpha1())\n    iex> parser.(\"abc\")\n    {:ok, \"\", \"abc\"}\n    iex> parser.(\"123\")\n    {:ok, \"123\", nil}","ref":"Elnom.Combinator.html#opt/1"},{"type":"function","title":"Elnom.Combinator.peek/1","doc":"Tries to apply its parser without consuming the input.\n\n    iex> parser = peek(alpha1())\n    iex> parser.(\"abcd;\")\n    {:ok, \"abcd;\", \"abcd\"}\n    iex> parser.(\"123;\")\n    {:error, %Error{kind: :alpha, buffer: \"123;\"}}","ref":"Elnom.Combinator.html#peek/1"},{"type":"function","title":"Elnom.Combinator.recognize/1","doc":"If the child parser was successful, return the consumed input as produced value.\n\n    iex> parser = recognize(separated_pair(alpha1(), char(\",\"), alpha1()))\n    iex> parser.(\"abcd,efgh\")\n    {:ok, \"\", \"abcd,efgh\"}\n    iex> parser.(\"abcd;\")\n    {:error, %Error{kind: :char, buffer: \";\"}}","ref":"Elnom.Combinator.html#recognize/1"},{"type":"function","title":"Elnom.Combinator.rest/0","doc":"Return the remaining input.\n\n    iex> parser = rest()\n    iex> parser.(\"abc\")\n    {:ok, \"\", \"abc\"}\n    iex> parser.(\"\")\n    {:ok, \"\", \"\"}","ref":"Elnom.Combinator.html#rest/0"},{"type":"function","title":"Elnom.Combinator.rest_len/0","doc":"Return the length of the remaining input.\n\n    iex> parser = rest_len()\n    iex> parser.(\"abc\")\n    {:ok, \"\", 3}\n    iex> parser.(\"\")\n    {:ok, \"\", 0}","ref":"Elnom.Combinator.html#rest_len/0"},{"type":"function","title":"Elnom.Combinator.success/1","doc":"A parser which always succeeds with given value without consuming any input.\n\n    iex> parser = success(10)\n    iex> parser.(\"abc\")\n    {:ok, \"abc\", 10}\n\n    iex> sign = alt({value(-1, char(\"-\")), value(1, char(\"+\")), success(1)})\n    iex> sign.(\"+10\")\n    {:ok, \"10\", 1}\n    iex> sign.(\"-10\")\n    {:ok, \"10\", -1}\n    iex> sign.(\"10\")\n    {:ok, \"10\", 1}","ref":"Elnom.Combinator.html#success/1"},{"type":"function","title":"Elnom.Combinator.value/2","doc":"Returns the provided value if the child parser succeeds.\n\n    iex> parser = value(1234, tag(\"abc\"))\n    iex> parser.(\"abc\")\n    {:ok, \"\", 1234}\n    iex> parser.(\"123\")\n    {:error, %Error{kind: :tag, buffer: \"123\"}}","ref":"Elnom.Combinator.html#value/2"},{"type":"function","title":"Elnom.Combinator.verify/2","doc":"Returns the result of the child parser if it satisfies a verification function.\n\nThe verification function takes as argument a reference to the output of the parser.\n\n    iex> parser = verify(alpha1(), &String.length(&1) == 4)\n    iex> parser.(\"abcd\")\n    {:ok, \"\", \"abcd\"}\n    iex> parser.(\"abcde\")\n    {:error, %Error{kind: :verify, buffer: \"abcde\"}}\n    iex> parser.(\"123abcd;\")\n    {:error, %Error{kind: :alpha, buffer: \"123abcd;\"}}","ref":"Elnom.Combinator.html#verify/2"},{"type":"module","title":"Elnom.Error","doc":"Error struct indicating a recoverable error has occurred during parsing.\n\nThe `kind` field is an atom indicating the kind of error that occurred.\n\nThe `buffer` field holds the input buffer at the time the error occurred.","ref":"Elnom.Error.html"},{"type":"function","title":"Elnom.Error.dbg_dmp/2","doc":"Dumps the parser output to the console if the parser returns an error.\n\n`context` is any value (usually a string) that will be printed before the\nerror message.","ref":"Elnom.Error.html#dbg_dmp/2"},{"type":"function","title":"Elnom.Error.new/2","doc":"Create a new Error struct.","ref":"Elnom.Error.html#new/2"},{"type":"module","title":"Elnom.Failure","doc":"Error struct indicating a unrecoverable error has occurred during parsing.\n\nThe `kind` field is an atom indicating the kind of error that occurred.\n\nThe `buffer` field holds the input buffer at the time the error occurred.","ref":"Elnom.Failure.html"},{"type":"function","title":"Elnom.Failure.new/1","doc":"Construct a Failure struct from an Error struct.","ref":"Elnom.Failure.html#new/1"},{"type":"function","title":"Elnom.Failure.new/2","doc":"Construct a new Failure struct.","ref":"Elnom.Failure.html#new/2"},{"type":"module","title":"Elnom.Incomplete","doc":"Error struct indicating more input is required by the parser.\n\nThe `needed` field is an integer indicating the number of bytes needed to\ncomplete the current parsing operation.","ref":"Elnom.Incomplete.html"},{"type":"function","title":"Elnom.Incomplete.new/1","doc":"Create a new Incomplete struct.","ref":"Elnom.Incomplete.html#new/1"},{"type":"module","title":"Elnom.Multi","doc":"Combinators applying their child parser multiple times","ref":"Elnom.Multi.html"},{"type":"function","title":"Elnom.Multi.count/2","doc":"Runs the embedded parser `count` times, gathering the results into a list\n\n    iex> parser = count(tag(\"abc\"), 2)\n    iex> parser.(\"abcabc\")\n    {:ok, \"\", [\"abc\", \"abc\"]}\n    iex> parser.(\"abc123\")\n    {:error, %Error{kind: :tag, buffer: \"123\"}}\n    iex> parser.(\"123123\")\n    {:error, %Error{kind: :tag, buffer: \"123123\"}}\n    iex> parser.(\"\")\n    {:error, %Error{kind: :tag, buffer: \"\"}}\n    iex> parser.(\"abcabcabc\")\n    {:ok, \"abc\", [\"abc\", \"abc\"]}","ref":"Elnom.Multi.html#count/2"},{"type":"function","title":"Elnom.Multi.fold_many0/3","doc":"Repeats the embedded parser, calling `fun` to gather the results.\n\nThis stops on Error. To instead chain an error up, see cut/1.\n\nWarning: the `element` and `accumulator` arguments passed to the `fun` are swapped relative to the Rust library so that they are idiomatic with Enum.reduce/2.\n\n    iex> parser = fold_many0(tag(\"abc\"), fn -> [] end, fn x, acc -> [[x] | acc] end)\n    iex> parser.(\"abcabc\")\n    {:ok, \"\", [[\"abc\"], [\"abc\"]]}\n    iex> parser.(\"abc123\")\n    {:ok, \"123\", [[\"abc\"]]}\n    iex> parser.(\"123123\")\n    {:ok, \"123123\", []}\n    iex> parser.(\"\")\n    {:ok, \"\", []}","ref":"Elnom.Multi.html#fold_many0/3"},{"type":"function","title":"Elnom.Multi.fold_many1/3","doc":"Repeats the embedded parser, calling `fun` to gather the results.\n\nThis stops on Error if there is at least one result. To instead chain an error up, see cut/1.\n\nWarning: the `element` and `accumulator` arguments passed to the `fun` are swapped relative to the Rust library so that they are idiomatic with Enum.reduce/2.\n\n    iex> parser = fold_many1(tag(\"abc\"), fn -> [] end, fn x, acc -> [[x] | acc] end)\n    iex> parser.(\"abcabc\")\n    {:ok, \"\", [[\"abc\"], [\"abc\"]]}\n    iex> parser.(\"abc123\")\n    {:ok, \"123\", [[\"abc\"]]}\n    iex> parser.(\"123123\")\n    {:error, %Error{kind: :many1, buffer: \"123123\"}}\n    iex> parser.(\"\")\n    {:error, %Error{kind: :many1, buffer: \"\"}}","ref":"Elnom.Multi.html#fold_many1/3"},{"type":"function","title":"Elnom.Multi.fold_many_m_n/5","doc":"Repeats the embedded parser m..=n times, calling g to gather the results\n\nThis stops before n when the parser returns Err::Error. To instead chain an error up, see cut.\n\nWarning: the `element` and `accumulator` arguments passed to the `fun` are swapped relative to the Rust library so that they are idiomatic with Enum.reduce/2.\n\n    iex> parser = fold_many_m_n(0, 2, tag(\"abc\"), fn -> [] end, fn x, acc -> [[x] | acc] end)\n    iex> parser.(\"abcabc\")\n    {:ok, \"\", [[\"abc\"], [\"abc\"]]}\n    iex> parser.(\"abc123\")\n    {:ok, \"123\", [[\"abc\"]]}\n    iex> parser.(\"123123\")\n    {:ok, \"123123\", []}\n    iex> parser.(\"\")\n    {:ok, \"\", []}\n    iex> parser.(\"abcabcabc\")\n    {:ok, \"abc\", [[\"abc\"], [\"abc\"]]}\n\n    iex> parser = fold_many_m_n(2, 2, tag(\"abc\"), fn -> [] end, fn x, acc -> [[x] | acc] end)\n    iex> parser.(\"abcabc\")\n    {:ok, \"\", [[\"abc\"], [\"abc\"]]}\n    iex> parser.(\"abc\")\n    {:error, %Error{kind: :many_m_n, buffer: \"\"}}\n    iex> parser.(\"\")\n    {:error, %Error{kind: :many_m_n, buffer: \"\"}}","ref":"Elnom.Multi.html#fold_many_m_n/5"},{"type":"function","title":"Elnom.Multi.length_count/2","doc":"Gets a number from the first parser, then applies the second parser that many times.\n\n    iex> parser = length_count(u8(), tag(\"abc\"))\n    iex> parser.( >)\n    {:ok, \"abc\", [\"abc\", \"abc\"]}\n    iex> parser.( >)\n    {:error, %Error{kind: :tag, buffer: \"123123123\"}}\n\n    iex> length_count(integer(), tag(\"abc\")).(\"2abcabcabc\")\n    {:ok, \"abc\", [\"abc\", \"abc\"]}","ref":"Elnom.Multi.html#length_count/2"},{"type":"function","title":"Elnom.Multi.length_data/2","doc":"Gets a number from the parser and returns a substring of the input of that size in utf-8 characters or bytes, depending on the `size` argument. If the parser returns Incomplete, length_data will return an error.\n\n    iex> parser = length_data(be_u16(), :utf8)\n    iex> parser.( >)\n    {:ok, \"efg\", \"ab💙\"}\n    iex> parser.( >)\n    {:error, %Incomplete{needed: 2}}\n\n    iex> parser = length_data(be_u16(), :byte)\n    iex> parser.( >)\n    {:ok,  >,  >}\n    iex> parser.( >)\n    {:error, %Incomplete{needed: 2}}","ref":"Elnom.Multi.html#length_data/2"},{"type":"function","title":"Elnom.Multi.length_value/3","doc":"Gets a number from the first parser, takes a substring of the input of that size in utf-8 characters or bytes (depending on the `size` argument), then applies the second parser on that substring. If the second parser returns Incomplete, length_value will return an error.\n\n    iex> parser = length_value(be_u16(), tag(\"ab💙\"), :utf8)\n    iex> parser.( >)\n    {:ok, \"efg\", \"ab💙\"}\n    iex> parser.( >)\n    {:error, %Error{kind: :tag, buffer: \"123\"}}\n    iex> parser.( >)\n    {:error, %Incomplete{needed: 2}}\n\n    iex> parser = length_value(be_u16(), tag(\"abc\"), :byte)\n    iex> parser.( >)\n    {:ok, \"efg\", \"abc\"}","ref":"Elnom.Multi.html#length_value/3"},{"type":"function","title":"Elnom.Multi.many0/1","doc":"Repeats the embedded parser, gathering the results in a list.\n\nThis stops on Error and returns the results that were accumulated. To instead chain an error up, see cut/1.\n\n    iex> parser = many0(tag(\"abc\"))\n    iex> parser.(\"abcabc\")\n    {:ok, \"\", [\"abc\", \"abc\"]}\n    iex> parser.(\"abc123\")\n    {:ok, \"123\", [\"abc\"]}\n    iex> parser.(\"123123\")\n    {:ok, \"123123\", []}\n    iex> parser.(\"\")\n    {:ok, \"\", []}\n    iex> parser.(\"abcabcabcxabc\")\n    {:ok, \"xabc\", [\"abc\", \"abc\", \"abc\"]}\n\n    iex> many0(alpha0()).(\"\")\n    {:error, %Error{kind: :many, buffer: \"\"}}","ref":"Elnom.Multi.html#many0/1"},{"type":"function","title":"Elnom.Multi.many0_count/1","doc":"Repeats the embedded parser, counting the results\n\nThis stops on Error. To instead chain an error up, see cut/1.\n\n    iex> parser = many0_count(tag(\"abc\"))\n    iex> parser.(\"abcabc\")\n    {:ok, \"\", 2}\n    iex> parser.(\"abc123\")\n    {:ok, \"123\", 1}\n    iex> parser.(\"123123\")\n    {:ok, \"123123\", 0}\n    iex> parser.(\"\")\n    {:ok, \"\", 0}\n    iex> parser.(\"abcabcabcxabc\")\n    {:ok, \"xabc\", 3}","ref":"Elnom.Multi.html#many0_count/1"},{"type":"function","title":"Elnom.Multi.many1/1","doc":"Runs the embedded parser, gathering the results in a Vec.\n\nThis stops on Error if there is at least one result, and returns the results that were accumulated. To instead chain an error up, see cut/1.\n\n    iex> parser = many1(tag(\"abc\"))\n    iex> parser.(\"abcabc\")\n    {:ok, \"\", [\"abc\", \"abc\"]}\n    iex> parser.(\"abc123\")\n    {:ok, \"123\", [\"abc\"]}\n    iex> parser.(\"123123\")\n    {:error, %Error{kind: :tag, buffer: \"123123\"}}\n    iex> parser.(\"\")\n    {:error, %Error{kind: :tag, buffer: \"\"}}","ref":"Elnom.Multi.html#many1/1"},{"type":"function","title":"Elnom.Multi.many1_count/1","doc":"Runs the embedded parser, counting the results.\n\nThis stops on Error if there is at least one result. To instead chain an error up, see cut/1.\n\n    iex> parser = many1_count(tag(\"abc\"))\n    iex> parser.(\"abcabc\")\n    {:ok, \"\", 2}\n    iex> parser.(\"abc123\")\n    {:ok, \"123\", 1}\n    iex> parser.(\"123123\")\n    {:error, %Error{kind: :tag, buffer: \"123123\"}}\n    iex> parser.(\"\")\n    {:error, %Error{kind: :tag, buffer: \"\"}}","ref":"Elnom.Multi.html#many1_count/1"},{"type":"function","title":"Elnom.Multi.many_m_n/3","doc":"Repeats the embedded parser m..n times\n\nThis stops before n when the parser returns Error and returns the results that were accumulated. To instead chain an error up, see cut/1.\n\n    iex> parser = many_m_n(0, 2, tag(\"abc\"))\n    iex> parser.(\"abcabc\")\n    {:ok, \"\", [\"abc\", \"abc\"]}\n    iex> parser.(\"abc123\")\n    {:ok, \"123\", [\"abc\"]}\n    iex> parser.(\"123123\")\n    {:ok, \"123123\", []}\n    iex> parser.(\"\")\n    {:ok, \"\", []}\n    iex> parser.(\"abcabcabc\")\n    {:ok, \"abc\", [\"abc\", \"abc\"]}\n\n    iex> parser = many_m_n(2, 2, tag(\"abc\"))\n    iex> parser.(\"abcabc\")\n    {:ok, \"\", [\"abc\", \"abc\"]}\n    iex> parser.(\"abc\")\n    {:error, %Error{kind: :many_m_n, buffer: \"\"}}\n    iex> parser.(\"\")\n    {:error, %Error{kind: :many_m_n, buffer: \"\"}}","ref":"Elnom.Multi.html#many_m_n/3"},{"type":"function","title":"Elnom.Multi.many_till/2","doc":"Applies the parser `parser` until the parser `until` produces a result.\n\nReturns a tuple of the results of `parser` in a list and the result of `until`.\n\n`parser` keeps going so long as `until` produces Error. To instead chain an error up, see cut/1.\n\n    iex> parser = many_till(tag(\"abc\"), tag(\"end\"))\n    iex> parser.(\"abcabcend\")\n    {:ok, \"\", {[\"abc\", \"abc\"], \"end\"}}\n    iex> parser.(\"abc123end\")\n    {:error, %Error{kind: :tag, buffer: \"123end\"}}\n    iex> parser.(\"123123end\")\n    {:error, %Error{kind: :tag, buffer: \"123123end\"}}\n    iex> parser.(\"\")\n    {:error, %Error{kind: :tag, buffer: \"\"}}\n    iex> parser.(\"abcendefg\")\n    {:ok, \"efg\", {[\"abc\"], \"end\"}}\n    iex> parser.(\"endabc\")\n    {:ok, \"abc\", {[], \"end\"}}","ref":"Elnom.Multi.html#many_till/2"},{"type":"function","title":"Elnom.Multi.separated_list0/2","doc":"Alternates between two parsers to produce a list of elements.\n\nThis stops when either parser returns Error and returns the results that were accumulated. To instead chain an error up, see cut/1.\n\n    iex> parser = separated_list0(tag(\"|\"), tag(\"abc\"))\n    iex> parser.(\"abc|abc|abc\")\n    {:ok, \"\", [\"abc\", \"abc\", \"abc\"]}\n    iex> parser.(\"abc123abc\")\n    {:ok, \"123abc\", [\"abc\"]}\n    iex> parser.(\"abc|def\")\n    {:ok, \"|def\", [\"abc\"]}\n    iex> parser.(\"\")\n    {:ok, \"\", []}\n    iex> parser.(\"def|abc\")\n    {:ok, \"def|abc\", []}\n\n    iex> parser = separated_list0(map(digit1(), &String.to_integer/1), tag(\"abc\"))\n    iex> parser.(\"abc23abc\")\n    {:ok, \"\", [\"abc\", \"abc\"]}","ref":"Elnom.Multi.html#separated_list0/2"},{"type":"function","title":"Elnom.Multi.separated_list1/2","doc":"Alternates between two parsers to produce a list of elements until Error.\n\nFails if the element parser does not produce at least one element.\n\nThis stops when either parser returns Error and returns the results that were accumulated. To instead chain an error up, see cut/1.\n\n    iex> parser = separated_list1(tag(\"|\"), tag(\"abc\"))\n    iex> parser.(\"abc|abc|abc\")\n    {:ok, \"\", [\"abc\", \"abc\", \"abc\"]}\n    iex> parser.(\"abc123abc\")\n    {:ok, \"123abc\", [\"abc\"]}\n    iex> parser.(\"abc|def\")\n    {:ok, \"|def\", [\"abc\"]}\n    iex> parser.(\"\")\n    {:error, %Error{kind: :tag, buffer: \"\"}}\n    iex> parser.(\"def|abc\")\n    {:error, %Error{kind: :tag, buffer: \"def|abc\"}}","ref":"Elnom.Multi.html#separated_list1/2"},{"type":"module","title":"Elnom.Number","doc":"Parsers recognizing numbers in binary and numeric-string formats","ref":"Elnom.Number.html"},{"type":"function","title":"Elnom.Number.be_f32/0","doc":"Recognizes a big endian 4 bytes floating point number.\n\n    iex> be_f32().( >)\n    {:ok, \"\", 12.5}\n\n    iex> be_f32().(\"abc\")\n    {:error, %Elnom.Error{buffer: \"abc\", kind: :eof}}","ref":"Elnom.Number.html#be_f32/0"},{"type":"function","title":"Elnom.Number.be_f64/0","doc":"Recognizes a big endian 8 bytes floating point number.\n\n    iex> be_f64().( >)\n    {:ok, \"\", 12.5}\n\n    iex> be_f64().(\"abcdefg\")\n    {:error, %Elnom.Error{buffer: \"abcdefg\", kind: :eof}}","ref":"Elnom.Number.html#be_f64/0"},{"type":"function","title":"Elnom.Number.be_i16/0","doc":"Recognizes an signed 2 byte integer in big endian format.\n\n    iex> be_i16().( >)\n    {:ok, \"abcefg\", 0x0103}\n\n    iex> be_i16().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#be_i16/0"},{"type":"function","title":"Elnom.Number.be_i24/0","doc":"Recognizes an signed 3 byte integer in big endian format.\n\n    iex> be_i24().( >)\n    {:ok, \"abcefg\", 0x010305}\n\n    iex> be_i24().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#be_i24/0"},{"type":"function","title":"Elnom.Number.be_i32/0","doc":"Recognizes an signed 4 byte integer in big endian format.\n\n    iex> be_i32().( >)\n    {:ok, \"abcefg\", 0x01030507}\n\n    iex> be_i32().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#be_i32/0"},{"type":"function","title":"Elnom.Number.be_i64/0","doc":"Recognizes an signed 8 byte integer in big endian format.\n\n    iex> be_i64().( >)\n    {:ok, \"abcefg\", 0x01030507090b0d0f}\n\n    iex> be_i64().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#be_i64/0"},{"type":"function","title":"Elnom.Number.be_i128/0","doc":"Recognizes an signed 16 byte integer in big endian format.\n\n    iex> be_i128().( >)\n    {:ok, \"abcefg\", 0x01030507090b0d0f11131517191b1d1f}\n\n    iex> be_i128().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#be_i128/0"},{"type":"function","title":"Elnom.Number.be_u16/0","doc":"Recognizes an unsigned 2 byte integer in big endian format.\n\n    iex> be_u16().( >)\n    {:ok, \"abcefg\", 0x0103}\n\n    iex> be_u16().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#be_u16/0"},{"type":"function","title":"Elnom.Number.be_u24/0","doc":"Recognizes an unsigned 3 byte integer in big endian format.\n\n    iex> be_u24().( >)\n    {:ok, \"abcefg\", 0x010305}\n\n    iex> be_u24().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#be_u24/0"},{"type":"function","title":"Elnom.Number.be_u32/0","doc":"Recognizes an unsigned 4 byte integer in big endian format.\n\n    iex> be_u32().( >)\n    {:ok, \"abcefg\", 0x01030507}\n\n    iex> be_u32().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#be_u32/0"},{"type":"function","title":"Elnom.Number.be_u64/0","doc":"Recognizes an unsigned 8 byte integer in big endian format.\n\n    iex> be_u64().( >)\n    {:ok, \"abcefg\", 0x01030507090b0d0f}\n\n    iex> be_u64().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#be_u64/0"},{"type":"function","title":"Elnom.Number.be_u128/0","doc":"Recognizes an unsigned 16 byte integer in big endian format.\n\n    iex> be_u128().( >)\n    {:ok, \"abcefg\", 0x01030507090b0d0f11131517191b1d1f}\n\n    iex> be_u128().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#be_u128/0"},{"type":"function","title":"Elnom.Number.double/0","doc":"Recognizes floating point number in text format and returns a float.\n\n    iex> float().(\"11e-1\")\n    {:ok, \"\", 1.1}\n\n    iex> float().(\"123E-02\")\n    {:ok, \"\", 1.23}\n\n    iex> float().(\"123K-01\")\n    {:ok, \"K-01\", 123.0}\n\n    iex> float().(\"abc\")\n    {:error, %Elnom.Error{buffer: \"abc\", kind: :float}}","ref":"Elnom.Number.html#double/0"},{"type":"function","title":"Elnom.Number.f32/1","doc":"Parse a 32-bit float as big endian if the argument is `:big` and little endian if `:little`.","ref":"Elnom.Number.html#f32/1"},{"type":"function","title":"Elnom.Number.f64/1","doc":"Parse a 64-bit double as big endian if the argument is `:big` and little endian if `:little`.","ref":"Elnom.Number.html#f64/1"},{"type":"function","title":"Elnom.Number.float/0","doc":"Elixir does not have a float type, so this function aliases to double/0.","ref":"Elnom.Number.html#float/0"},{"type":"function","title":"Elnom.Number.hex_u32/0","doc":"Parses a hex-encoded integer.\n\n    iex> hex_u32().(\"01AE\")\n    {:ok, \"\", 0x01AE}\n\n    iex> hex_u32().(\"abc\")\n    {:ok, \"\", 0x0ABC}\n\n    iex> hex_u32().(\"012345678\")\n    {:ok, \"8\", 0x01234567}\n\n    iex> hex_u32().(\"ggg\")\n    {:error, %Elnom.Error{buffer: \"ggg\", kind: :take_while_m_n}}","ref":"Elnom.Number.html#hex_u32/0"},{"type":"function","title":"Elnom.Number.i8/0","doc":"Recognizes a signed 1 byte integer.\n\n    iex> i8().( >)\n    {:ok,  >, 0}\n\n    iex> i8().( >)\n    {:ok,  >, -1}\n\n    iex> i8().(\"\")\n    {:error, %Elnom.Error{buffer: \"\", kind: :eof}}","ref":"Elnom.Number.html#i8/0"},{"type":"function","title":"Elnom.Number.i16/1","doc":"Parse a i16 integer as big endian if the argument is `:big` and little endian if `:little`.","ref":"Elnom.Number.html#i16/1"},{"type":"function","title":"Elnom.Number.i24/1","doc":"Parse a i24 integer as big endian if the argument is `:big` and little endian if `:little`.","ref":"Elnom.Number.html#i24/1"},{"type":"function","title":"Elnom.Number.i32/1","doc":"Parse a i32 integer as big endian if the argument is `:big` and little endian if `:little`.","ref":"Elnom.Number.html#i32/1"},{"type":"function","title":"Elnom.Number.i64/1","doc":"Parse a i64 integer as big endian if the argument is `:big` and little endian if `:little`.","ref":"Elnom.Number.html#i64/1"},{"type":"function","title":"Elnom.Number.i128/1","doc":"Parse a i128 integer as big endian if the argument is `:big` and little endian if `:little`.","ref":"Elnom.Number.html#i128/1"},{"type":"function","title":"Elnom.Number.le_f32/0","doc":"Recognizes a little endian 4 bytes floating point number.\n\n    iex> le_f32().( >)\n    {:ok, \"\", 12.5}\n\n    iex> le_f32().(\"abc\")\n    {:error, %Elnom.Error{buffer: \"abc\", kind: :eof}}","ref":"Elnom.Number.html#le_f32/0"},{"type":"function","title":"Elnom.Number.le_f64/0","doc":"Recognizes a little endian 8 bytes floating point number.\n\n    iex> le_f64().( >)\n    {:ok, \"\", 12.5}\n\n    iex> le_f64().(\"abcdefg\")\n    {:error, %Elnom.Error{buffer: \"abcdefg\", kind: :eof}}","ref":"Elnom.Number.html#le_f64/0"},{"type":"function","title":"Elnom.Number.le_i16/0","doc":"Recognizes an signed 2 byte integer in little endian format.\n\n    iex> le_i16().( >)\n    {:ok, \"abcefg\", 0x0301}\n\n    iex> le_i16().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#le_i16/0"},{"type":"function","title":"Elnom.Number.le_i24/0","doc":"Recognizes an signed 3 byte integer in little endian format.\n\n    iex> le_i24().( >)\n    {:ok, \"abcefg\", 0x050301}\n\n    iex> le_i24().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#le_i24/0"},{"type":"function","title":"Elnom.Number.le_i32/0","doc":"Recognizes an signed 4 byte integer in little endian format.\n\n    iex> le_i32().( >)\n    {:ok, \"abcefg\", 0x07050301}\n\n    iex> le_i32().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#le_i32/0"},{"type":"function","title":"Elnom.Number.le_i64/0","doc":"Recognizes an signed 8 byte integer in little endian format.\n\n    iex> le_i64().( >)\n    {:ok, \"abcefg\", 0x0f0d0b0907050301}\n\n    iex> le_i64().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#le_i64/0"},{"type":"function","title":"Elnom.Number.le_i128/0","doc":"Recognizes an signed 16 byte integer in little endian format.\n\n    iex> le_i128().( >)\n    {:ok, \"abcefg\", 0x1f1d1b19171513110f0d0b0907050301}\n\n    iex> le_i128().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#le_i128/0"},{"type":"function","title":"Elnom.Number.le_u16/0","doc":"Recognizes an unsigned 2 byte integer in little endian format.\n\n    iex> le_u16().( >)\n    {:ok, \"abcefg\", 0x0301}\n\n    iex> le_u16().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#le_u16/0"},{"type":"function","title":"Elnom.Number.le_u24/0","doc":"Recognizes an unsigned 3 byte integer in little endian format.\n\n    iex> le_u24().( >)\n    {:ok, \"abcefg\", 0x050301}\n\n    iex> le_u24().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#le_u24/0"},{"type":"function","title":"Elnom.Number.le_u32/0","doc":"Recognizes an unsigned 4 byte integer in little endian format.\n\n    iex> le_u32().( >)\n    {:ok, \"abcefg\", 0x07050301}\n\n    iex> le_u32().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#le_u32/0"},{"type":"function","title":"Elnom.Number.le_u64/0","doc":"Recognizes an unsigned 8 byte integer in little endian format.\n\n    iex> le_u64().( >)\n    {:ok, \"abcefg\", 0x0f0d0b0907050301}\n\n    iex> le_u64().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#le_u64/0"},{"type":"function","title":"Elnom.Number.le_u128/0","doc":"Recognizes an unsigned 16 byte integer in little endian format.\n\n    iex> le_u128().( >)\n    {:ok, \"abcefg\", 0x1f1d1b19171513110f0d0b0907050301}\n\n    iex> le_u128().( >)\n    {:error, %Elnom.Error{buffer:  >, kind: :eof}}","ref":"Elnom.Number.html#le_u128/0"},{"type":"function","title":"Elnom.Number.recognize_float/0","doc":"Recognizes floating point number in a byte string and returns the corresponding string.\n\n    iex> recognize_float().(\"11e-1\")\n    {:ok, \"\", \"11e-1\"}\n\n    iex> recognize_float().(\"123E-02\")\n    {:ok, \"\", \"123E-02\"}\n\n    iex> recognize_float().(\"123K-01\")\n    {:ok, \"K-01\", \"123\"}\n\n    iex> recognize_float().(\"abc\")\n    {:error, %Elnom.Error{buffer: \"abc\", kind: :float}}","ref":"Elnom.Number.html#recognize_float/0"},{"type":"function","title":"Elnom.Number.u8/0","doc":"Recognizes an unsigned 1 byte integer.\n\n    iex> u8().( >)\n    {:ok,  >, 0}\n\n    iex> u8().(\"\")\n    {:error, %Elnom.Error{buffer: \"\", kind: :eof}}","ref":"Elnom.Number.html#u8/0"},{"type":"function","title":"Elnom.Number.u16/1","doc":"Parse a u16 integer as big endian if the argument is `:big` and little endian if `:little`.","ref":"Elnom.Number.html#u16/1"},{"type":"function","title":"Elnom.Number.u24/1","doc":"Parse a u24 integer as big endian if the argument is `:big` and little endian if `:little`.","ref":"Elnom.Number.html#u24/1"},{"type":"function","title":"Elnom.Number.u32/1","doc":"Parse a u32 integer as big endian if the argument is `:big` and little endian if `:little`.","ref":"Elnom.Number.html#u32/1"},{"type":"function","title":"Elnom.Number.u64/1","doc":"Parse a u64 integer as big endian if the argument is `:big` and little endian if `:little`.","ref":"Elnom.Number.html#u64/1"},{"type":"function","title":"Elnom.Number.u128/1","doc":"Parse a u128 integer as big endian if the argument is `:big` and little endian if `:little`.","ref":"Elnom.Number.html#u128/1"},{"type":"module","title":"Elnom.Sequence","doc":"Combinators applying parsers in sequence","ref":"Elnom.Sequence.html"},{"type":"function","title":"Elnom.Sequence.delimited/3","doc":"Matches an object from the first parser and discards it, then gets an object from the second parser, and finally matches an object from the third parser and discards it.\n\n      iex> parser = delimited(tag(\"(\"), tag(\"abc\"), tag(\")\"))\n      iex> parser.(\"(abc)\")\n      {:ok, \"\", \"abc\"}\n      iex> parser.(\"(abc)def\")\n      {:ok, \"def\", \"abc\"}\n      iex> parser.(\"\")\n      {:error, %Error{kind: :tag, buffer: \"\"}}\n      iex> parser.(\"123\")\n      {:error, %Error{kind: :tag, buffer: \"123\"}}","ref":"Elnom.Sequence.html#delimited/3"},{"type":"function","title":"Elnom.Sequence.pair/2","doc":"Gets an object from the first parser, then gets another object from the second parser.\n\n    iex> parser = pair(tag(\"abc\"), tag(\"efg\"))\n    iex> parser.(\"abcefg\")\n    {:ok, \"\", {\"abc\", \"efg\"}}\n    iex> parser.(\"abcefg123\")\n    {:ok, \"123\", {\"abc\", \"efg\"}}\n    iex> parser.(\"\")\n    {:error, %Error{kind: :tag, buffer: \"\"}}\n    iex> parser.(\"123\")\n    {:error, %Error{kind: :tag, buffer: \"123\"}}","ref":"Elnom.Sequence.html#pair/2"},{"type":"function","title":"Elnom.Sequence.preceded/2","doc":"Matches an object from the first parser and discards it, then gets an object from the second parser.\n\n    iex> parser = preceded(tag(\"abc\"), tag(\"efg\"))\n    iex> parser.(\"abcefg\")\n    {:ok, \"\", \"efg\"}\n    iex> parser.(\"abcefghij\")\n    {:ok, \"hij\", \"efg\"}\n    iex> parser.(\"\")\n    {:error, %Error{kind: :tag, buffer: \"\"}}\n    iex> parser.(\"123\")\n    {:error, %Error{kind: :tag, buffer: \"123\"}}","ref":"Elnom.Sequence.html#preceded/2"},{"type":"function","title":"Elnom.Sequence.separated_pair/3","doc":"Gets an object from the first parser, then matches an object from the sep_parser and discards it, then gets another object from the second parser.\n\n    iex> parser = separated_pair(tag(\"abc\"), tag(\"|\"), tag(\"efg\"))\n    iex> parser.(\"abc|efg\")\n    {:ok, \"\", {\"abc\", \"efg\"}}\n    iex> parser.(\"abc|efg123\")\n    {:ok, \"123\", {\"abc\", \"efg\"}}\n    iex> parser.(\"\")\n    {:error, %Error{kind: :tag, buffer: \"\"}}\n    iex> parser.(\"123\")\n    {:error, %Error{kind: :tag, buffer: \"123\"}}","ref":"Elnom.Sequence.html#separated_pair/3"},{"type":"function","title":"Elnom.Sequence.terminated/2","doc":"Gets an object from the first parser, then matches an object from the second parser and discards it.\n\n    iex> parser = terminated(tag(\"abc\"), tag(\"efg\"))\n    iex> parser.(\"abcefg\")\n    {:ok, \"\", \"abc\"}\n    iex> parser.(\"abcefg123\")\n    {:ok, \"123\", \"abc\"}\n    iex> parser.(\"\")\n    {:error, %Error{kind: :tag, buffer: \"\"}}\n    iex> parser.(\"123\")\n    {:error, %Error{kind: :tag, buffer: \"123\"}}","ref":"Elnom.Sequence.html#terminated/2"},{"type":"function","title":"Elnom.Sequence.tuple/1","doc":"Applies a tuple of parsers one by one and returns their results as a tuple.\n\nEither a tuple or a list of parsers can be provided.\n\n    iex> parser = tuple({alpha1(), digit1(), alpha1()})\n    iex> parser.(\"abc123def\")\n    {:ok, \"\", {\"abc\", \"123\", \"def\"}}\n    iex> parser.(\"123def\")\n    {:error, %Error{kind: :alpha, buffer: \"123def\"}}","ref":"Elnom.Sequence.html#tuple/1"},{"type":"module","title":"Elnom.Strings.Complete","doc":"Parsers recognising utf-8 strings.\n\nIf you're working with binary (non-utf8) data, use `Elnom.Bytes.Complete` instead.","ref":"Elnom.Strings.Complete.html"},{"type":"function","title":"Elnom.Strings.Complete.escaped/3","doc":"Matches a string with escaped characters.\n\nThe first argument matches the normal characters (it must not accept the control character)\nThe second argument is the control character (like \\\\ in most languages)\nThe third argument matches the escaped characters\n\n    iex> esc = escaped(digit1(), \"\\\\\", one_of(\"rn;\"))\n    iex> esc.(\"123;\")\n    {:ok, \";\", \"123\"}\n    iex> esc.(\"123\\\\;456;\")\n    {:ok, \";\", \"123\\\\;456\"}","ref":"Elnom.Strings.Complete.html#escaped/3"},{"type":"function","title":"Elnom.Strings.Complete.escaped_transform/3","doc":"Matches a byte string with escaped characters.\n\n* The first argument matches the normal characters (it must not match the control character)\n* The second argument is the control character (like \\ in most languages)\n* The third argument matches the escaped characters and transforms them\n\nAs an example, the chain `abc\\tdef` could be `abc    def` (it also consumes the control character)\n\n    iex> esc = escaped_transform(\n    ...>   alpha1(),\n    ...>   \"\\\\\",\n    ...>   alt({\n    ...>     value(\"\\\\\", tag(\"\\\\\")),\n    ...>     value(\"\\\"\", tag(\"\\\"\")),\n    ...>     value(\"\\n\", tag(\"n\"))\n    ...>   })\n    ...> )\n    iex> esc.(\"abc\")\n    {:ok, \"\", \"abc\"}\n    iex> esc.(\"ab\\\\\\\"cd\")\n    {:ok, \"\", \"ab\\\"cd\"}\n    iex> esc.(\"ab\\\\ncd\")\n    {:ok, \"\", \"ab\\ncd\"}","ref":"Elnom.Strings.Complete.html#escaped_transform/3"},{"type":"function","title":"Elnom.Strings.Complete.is_a/1","doc":"Returns the longest substring of the matches the pattern.\n\nThe parser will return the longest substring consisting of the characters in provided in the combinator’s argument.\n\nIt will return an Error if the pattern wasn’t met.\n\n    iex> hex = is_a(\"0123456789ABCDEF\")\n    iex> hex.(\"123 and voila\")\n    {:ok, \" and voila\", \"123\"}\n    iex> hex.(\"DEADBEEF and others\")\n    {:ok, \" and others\", \"DEADBEEF\"}\n    iex> hex.(\"D15EA5E\")\n    {:ok, \"\", \"D15EA5E\"}\n    iex> hex.(\"other\")\n    {:error, %Error{kind: :is_a, buffer: \"other\"}}\n    iex> hex.(\"\")\n    {:error, %Error{kind: :is_a, buffer: \"\"}}","ref":"Elnom.Strings.Complete.html#is_a/1"},{"type":"function","title":"Elnom.Strings.Complete.is_not/1","doc":"Parse till certain characters are met.\n\nThe parser will return the longest substring till one of the characters of the combinator’s argument are met.\n\nIt doesn’t consume the matched character.\n\n    iex> not_space = is_not(\" \\t\\r\\n\")\n    iex> not_space.(\"Hello, World!\")\n    {:ok, \" World!\", \"Hello,\"}\n    iex> not_space.(\"Sometimes\\t\")\n    {:ok, \"\\t\", \"Sometimes\"}\n    iex> not_space.(\"Nospace\")\n    {:ok, \"\", \"Nospace\"}\n    iex> not_space.(\" hello\")\n    {:error, %Error{kind: :is_not, buffer: \" hello\"}}\n    iex> not_space.(\"\")\n    {:error, %Error{kind: :is_not, buffer: \"\"}}","ref":"Elnom.Strings.Complete.html#is_not/1"},{"type":"function","title":"Elnom.Strings.Complete.tag/1","doc":"Recognizes a pattern\n\nThe input data will be compared to the tag combinator’s argument and will return the part of the input that matches the argument.\n\nIt will return an Error if the input doesn’t match the pattern.\n\n    iex> tag(\"hello\").(\"hello there\")\n    {:ok, \" there\", \"hello\"}\n    iex> tag(\"hello\").(\"bye\")\n    {:error, %Error{kind: :tag, buffer: \"bye\"}}\n    iex> tag(\"\").(\"bye\")\n    {:ok, \"bye\", \"\"}\n    iex> tag(\"💙\").(\"💙💙\")\n    {:ok, \"💙\", \"💙\"}","ref":"Elnom.Strings.Complete.html#tag/1"},{"type":"function","title":"Elnom.Strings.Complete.tag_no_case/1","doc":"Recognizes a case insensitive pattern.\n\nThe input data will be compared to the tag combinator’s argument and will return the part of the input that matches the argument with no regard to case.\n\nIt will return an Error if the input doesn’t match the pattern.\n\n    iex> parser = tag_no_case(\"hello\")\n    iex> parser.(\"Hello, World!\")\n    {:ok, \", World!\", \"Hello\"}\n    iex> parser.(\"hello, World!\")\n    {:ok, \", World!\", \"hello\"}\n    iex> parser.(\"HeLlO, World!\")\n    {:ok, \", World!\", \"HeLlO\"}\n    iex> parser.(\"Something\")\n    {:error, %Error{kind: :tag, buffer: \"Something\"}}\n    iex> parser.(\"\")\n    {:error, %Error{kind: :tag, buffer: \"\"}}","ref":"Elnom.Strings.Complete.html#tag_no_case/1"},{"type":"function","title":"Elnom.Strings.Complete.take/1","doc":"Returns an input substring containing the first `count` utf-8 input characters.\n\nIt will return Error if the input is shorter than the argument.\n\n    iex> take6 = take(6)\n    iex> take6.(\"1234567\")\n    {:ok, \"7\", \"123456\"}\n    iex> take6.(\"things\")\n    {:ok, \"\", \"things\"}\n    iex> take6.(\"short\")\n    {:error, %Error{kind: :eof, buffer: \"short\"}}\n    iex> take6.(\"\")\n    {:error, %Error{kind: :eof, buffer: \"\"}}\n    iex> take(1).(\"💙\")\n    {:ok, \"\", \"💙\"}","ref":"Elnom.Strings.Complete.html#take/1"},{"type":"function","title":"Elnom.Strings.Complete.take_till1/1","doc":"Returns the longest input substring (at least 1) till a predicate is met.\n\nThe parser will return the longest substring till the given predicate (a function that takes the input and returns a bool).\n\nIt will return Error if the input is empty or the predicate matches the first input.\n\n    iex> till_colon = take_till1(fn char -> char == ?: end)\n    iex> till_colon.(\"latin:123\")\n    {:ok, \":123\", \"latin\"}\n    iex> till_colon.(\":empty matched\")\n    {:error, %Error{kind: :take_till1, buffer: \":empty matched\"}}\n    iex> till_colon.(\"12345\")\n    {:ok, \"\", \"12345\"}\n    iex> till_colon.(\"\")\n    {:error, %Error{kind: :take_till1, buffer: \"\"}}","ref":"Elnom.Strings.Complete.html#take_till1/1"},{"type":"function","title":"Elnom.Strings.Complete.take_till/1","doc":"Returns the longest input substring (if any) till a predicate is met.\n\nThe parser will return the longest substring till the given predicate (a function that takes the input and returns a bool).\n\n    iex> till_colon = take_till(fn char -> char == ?\\: end)\n    iex> till_colon.(\"latin:123\")\n    {:ok, \":123\", \"latin\"}\n    iex> till_colon.(\":empty matched\")\n    {:ok, \":empty matched\", \"\"}\n    iex> till_colon.(\"12345\")\n    {:ok, \"\", \"12345\"}\n    iex> till_colon.(\"\")\n    {:ok, \"\", \"\"}","ref":"Elnom.Strings.Complete.html#take_till/1"},{"type":"function","title":"Elnom.Strings.Complete.take_until1/1","doc":"Returns the non empty input substring up to the first occurrence of the pattern.\n\nIt doesn’t consume the pattern. It will return Error if the pattern wasn’t met.\n\n    iex> until_eof = take_until1(\"eof\")\n    iex> until_eof.(\"hello, worldeof\")\n    {:ok, \"eof\", \"hello, world\"}\n    iex> until_eof.(\"hello, world\")\n    {:error, %Error{kind: :take_until, buffer: \"hello, world\"}}\n    iex> until_eof.(\"eof\")\n    {:error, %Error{kind: :take_until, buffer: \"eof\"}}\n    iex> until_eof.(\"\")\n    {:error, %Error{kind: :take_until, buffer: \"\"}}\n    iex> until_eof.(\"1eof2eof\")\n    {:ok, \"eof2eof\", \"1\"}","ref":"Elnom.Strings.Complete.html#take_until1/1"},{"type":"function","title":"Elnom.Strings.Complete.take_until/1","doc":"Returns the input substring up to the first occurrence of the pattern.\n\nIt doesn’t consume the pattern. It will return Error if the pattern wasn’t met.\n\n    iex> until_eof = take_until(\"eof\")\n    iex> until_eof.(\"hello, worldeof\")\n    {:ok, \"eof\", \"hello, world\"}\n    iex> until_eof.(\"hello, world\")\n    {:error, %Error{kind: :take_until, buffer: \"hello, world\"}}\n    iex> until_eof.(\"eof\")\n    {:ok, \"eof\", \"\"}\n    iex> until_eof.(\"\")\n    {:error, %Error{kind: :take_until, buffer: \"\"}}\n    iex> until_eof.(\"1eof2eof\")\n    {:ok, \"eof2eof\", \"1\"}","ref":"Elnom.Strings.Complete.html#take_until/1"},{"type":"function","title":"Elnom.Strings.Complete.take_while1/2","doc":"Returns the longest (at least 1) input substring that matches the predicate.\n\nThe parser will return the longest substring that matches the given predicate (a function that takes the input and returns a bool).\n\nIt will return an Error if the pattern wasn’t met.\n\n    iex> alpha = take_while1(&is_alphabetic/1)\n    iex> alpha.(\"latin123\")\n    {:ok, \"123\", \"latin\"}\n    iex> alpha.(\"12345\")\n    {:error, %Error{kind: :take_while1, buffer: \"12345\"}}\n    iex> alpha.(\"latin\")\n    {:ok, \"\", \"latin\"}\n    iex> alpha.(\"\")\n    {:error, %Error{kind: :take_while1, buffer: \"\"}}","ref":"Elnom.Strings.Complete.html#take_while1/2"},{"type":"function","title":"Elnom.Strings.Complete.take_while/1","doc":"Returns the longest input substring (if any) that matches the predicate.\n\nThe parser will return the longest substring that matches the given predicate (a function that takes the input and returns a bool).\n\n    iex> alpha = take_while(&is_alphabetic/1)\n    iex> alpha.(\"latin123\")\n    {:ok, \"123\", \"latin\"}\n    iex> alpha.(\"12345\")\n    {:ok, \"12345\", \"\"}\n    iex> alpha.(\"latin\")\n    {:ok, \"\", \"latin\"}\n    iex> alpha.(\"\") == {:ok, \"\", \"\"}","ref":"Elnom.Strings.Complete.html#take_while/1"},{"type":"function","title":"Elnom.Strings.Complete.take_while_m_n/3","doc":"Returns the longest (min   short_alpha = take_while_m_n(3, 6, &is_alphabetic/1)\n    iex> short_alpha.(\"latin123\")\n    {:ok, \"123\", \"latin\"}\n    iex> short_alpha.(\"lengthy\")\n    {:ok, \"y\", \"length\"}\n    iex> short_alpha.(\"latin\")\n    {:ok, \"\", \"latin\"}\n    iex> short_alpha.(\"ed\")\n    {:error, %Error{kind: :take_while_m_n, buffer: \"ed\"}}\n    iex> short_alpha.(\"12345\")\n    {:error, %Error{kind: :take_while_m_n, buffer: \"12345\"}}","ref":"Elnom.Strings.Complete.html#take_while_m_n/3"},{"type":"extras","title":"elnom introduction","doc":"# elnom, an Elixir port of the Rust nom parser\n\n[nom](https://github.com/rust-bakery/nom/tree/main) is a fantastic parser combinator for Rust.  `elnom` is an\nElixir port, trying to stay as true as possible to nom's design.\n\nThe function calls are almost identical, so the [nom\ndocumentation](https://github.com/rust-bakery/nom/tree/main#documentation) is an excellent place to start to learn\nabout how to use elnom, or look at the [elnom documentation](https://hexdocs.pm/elnom).","ref":"readme.html"},{"type":"extras","title":"Example - elnom introduction","doc":"```elixir\ndefmodule Color do\n  use Elnom, type: :string\n\n  defstruct [:red, :green, :blue]\n\n  def new_from_string(string) do\n    case hex_color().(string) do\n      {:ok, \"\", color} -> {:ok, color}\n      {:error, reason} -> {:error, reason}\n    end\n  end\n\n  defp hex_color do\n    map(\n      all_consuming(\n        preceded(tag(\"#\"), count(hex_primary(), 3)),\n      )\n      fn [r, g, b] -> %Color{red: r, green: g, blue: b} end\n    )\n  end\n\n  defp hex_primary do\n    map(\n      take_while_m_n(2, 2, &is_hex_digit/1),\n      fn hex -> String.to_integer(hex, 16) end\n    )\n  end\nend\n\nColor.new_from_string(\"#2F14DF\") #=> {:ok, %Color{red: 47, green: 20, blue: 223}}\n```","ref":"readme.html#example"},{"type":"extras","title":"Installation - elnom introduction","doc":"Add `elnom` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:elnom, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Using it - elnom introduction","doc":"Add `use Elnom, type: :string` or `use Elnom, type: :byte` to your module, depending on whether you are parsing\nutf-8 strings or raw binary data.  This imports all of the elnom modules straight into your module, ready for use.\nAlternatively you can import just the functions you need, or even call the functions directly.\n\nAll parser functions return a function, and you can call that function with your input string/binary to get it\nstarted.\n\nSuccessful parses return `{:ok, remaining_buffer, output}`, and failed parses return `{:error, %{}}` where the\nmap is one of `Elnom.Error` (recoverable error), `Elnom.Failure` (unrecoverable error), or `Elnom.Incomplete`\n(more data required.)\n\n```elixir\nalpha1().(\"hello world\") #=> {:ok, \" world\", \"hello\"}\n\ndigit1().(\"not a number\") #=> {:error, %Elnom.Error{kind: :digit, buffer: \"not a number\"}}\n```\n\nParser functions are composable, so you build up your parser before executing it.\n\n```elixir\nseparated_list1(is_a(\" -\"), digit1()).(\"555 555-1212\") #=> {:ok, \"\", [\"555\", \"555\", \"1212\"]}\n```\n\nKeep adding functions.  There are a couple dozen to learn, and you can easily make your own.\n\n```elixir\nall_consuming(                                  # ensure all the input text is matched\n    tuple({                                     # match on these one after the other\n        delimited(                              # match the start & end characters and throw them away\n            char(\"(\"),                          # (start character) \n            take_while_m_n(3, 3, &is_digit/1),  # take exactly 3 digits\n            tag(\") \")                           # (end characters)\n        ),\n        terminated(                             # match the end characters and throw them away\n            take_while_m_n(3, 3, &is_digit/1),  # take exactly 3 digits\n            one_of(\"- \")                        # (end characters, either a \"-\" or a \" \")\n        ),\n        take_while_m_n(4, 4, &is_digit/1),      # take exactly 4 digits\n    })\n).(\"(555) 555-1212\")\n#=> {:ok, \"\", [\"555\", \"555\", \"1212\"]}\n```\n\nBy default, most parser functions return strings.  With `map/1` though you can map them into your own data format.\n\n```elixir\nmap(\n    separated_list1(\n        char(\" \"),\n        tuple({\n            terminated(\n                map(\n                    digit1(),\n                    &String.to_integer/1\n                ),\n                char(\":\")\n            ),\n            take_till(&is_space/1)\n        })\n    ),\n    &Map.new/1\n).(\"1:foxes 4:banana 10:pumpkin\")\n#=> {:ok, \"\", %{1 => \"foxes\", 4 => \"banana\", 10 => \"pumpkin\"}}\n```","ref":"readme.html#using-it"},{"type":"extras","title":"Differences with nom - elnom introduction","doc":"#","ref":"readme.html#differences-with-nom"},{"type":"extras","title":"Strings vs bitstrings - elnom introduction","doc":"Because Elixir's bitstrings and strings are the same type, you'll need to select the right module to use.\n\nYou most likely want to use `Elnom.Strings.Complete` which has exactly the same functions but works with strings\nand handles utf-8 characters. `Elnom.Bytes.Complete` is only for use when using bitstreams and will not handle\nutf-8 characters.  \n\n#","ref":"readme.html#strings-vs-bitstrings"},{"type":"extras","title":"No streaming support - elnom introduction","doc":"nom has support for streamed matching.  elnom does not support this (yet).","ref":"readme.html#no-streaming-support"}],"content_type":"text/markdown"}